@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bookmarkPlugin.h"
@@ -46,7 +46,7 @@ void bookmarkPlugin::parseBookmarks()
 {
     clear();
     const QString bmf(c2bUtils::fileToString(_bookmark_file));
-    QStringList bookmarks(bmf.split(QRegExp("[\\r\\n]"), QString::KeepEmptyParts));
+    QStringList bookmarks(bmf.split(QRegExp("[\\r\\n]"), _QT_6_KeepEmptyParts));
     const QRegExp _bookmark("^editorbookmark=");
     const QRegExp _separator("^editorbookmark=\\s*$");
     for (int i = 0; i < bookmarks.count(); ++i)
@@ -59,7 +59,7 @@ void bookmarkPlugin::parseBookmarks()
         if (bookmarks.at(i).contains(_bookmark))
         {
             bookmarks[i].remove(_bookmark);
-            const QStringList bm_parts(bookmarks.at(i).split('|', QString::KeepEmptyParts));
+            const QStringList bm_parts(bookmarks.at(i).split('|', _QT_6_KeepEmptyParts));
             if (bm_parts.count() != 4)
             {
                 c2bUtils::warn(tr("bookmarkPlugin::parseBookmarks: Syntax error at '%1'").arg(bookmarks.at(i)));
