@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -14,7 +14,7 @@
 
 namespace
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)) && (QT_VERSION < QT_VERSION_CHECK(5, 12, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::DontCaptureOption |
         QRegularExpression::UseUnicodePropertiesOption |
         QRegularExpression::OptimizeOnFirstUsageOption);
@@ -37,7 +37,7 @@ approximatePattern::approximatePattern(const QString& pattern, const Qt::CaseSen
 void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensitivity cs)
 {
     _string = pattern;
-    _subpatterns = pattern.split(c2bUtils::nonLetter, QString::SkipEmptyParts);
+    _subpatterns = pattern.split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
     _case_sensitivity = cs;
     _is_multipattern = false;
     _matched_length = -1;
@@ -57,8 +57,8 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
         return;
     }
     // Multiple words
-    _prefixes = c2bUtils::fileToString(":/txt/txt/prefixes.txt").split(c2bUtils::nonLetter, QString::SkipEmptyParts);
-    _suffixes = c2bUtils::fileToString(":/txt/txt/suffixes.txt").split(c2bUtils::nonLetter, QString::SkipEmptyParts);
+    _prefixes = c2bUtils::fileToString(":/txt/txt/prefixes.txt").split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
+    _suffixes = c2bUtils::fileToString(":/txt/txt/suffixes.txt").split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
     splitPattern();
     if (_string_pieces.count() < 3) // Cases: "qq pp", "qqq pp", etc
     {
