@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "authorString.h"
@@ -97,18 +97,18 @@ QString unifier::fromMedline(const QString& author) const
     QString LastN;
     if (FullN.contains(',')) // Some FAU are 'Last1 Last2, First'
     {
-        parts = FullN.split(',', QString::SkipEmptyParts);
+        parts = FullN.split(',', _QT_6_SkipEmptyParts);
         if (parts.count() > 1)
             LastN = parts.takeFirst();
     }
     else
     {
-        parts = FullN.split(' ', QString::SkipEmptyParts);
+        parts = FullN.split(' ', _QT_6_SkipEmptyParts);
         if (parts.count() > 1)
             LastN = parts.takeFirst();
     }
     FullN = parts.join(" ");
-    parts = FullN.split(' ', QString::SkipEmptyParts);
+    parts = FullN.split(' ', _QT_6_SkipEmptyParts);
     if (!LastN.isEmpty())
         if (c2bUtils::isUpperCaseString(LastN))
         {
@@ -467,27 +467,27 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
         QString last_name;
         if (is_current_reversed)
         {
-            const QStringList parts(author_i.split(',', QString::SkipEmptyParts));
+            const QStringList parts(author_i.split(',', _QT_6_SkipEmptyParts));
             const int nparts(parts.count());
             if (nparts == 2)
             {
-                QStringList p(parts.first().split(' ', QString::SkipEmptyParts));
+                QStringList p(parts.first().split(' ', _QT_6_SkipEmptyParts));
                 if (p.count() > 0)
                     last_name = p.takeLast();
-                fore_name_parts = parts.last().split(' ', QString::SkipEmptyParts) + p;
+                fore_name_parts = parts.last().split(' ', _QT_6_SkipEmptyParts) + p;
             }
             else if (nparts == 3)
             {
-                QStringList p(parts.first().split(' ', QString::SkipEmptyParts));
+                QStringList p(parts.first().split(' ', _QT_6_SkipEmptyParts));
                 if (p.count() > 0)
                     last_name = p.takeLast();
-                fore_name_parts = parts.at(1).split(' ', QString::SkipEmptyParts) + p;
+                fore_name_parts = parts.at(1).split(' ', _QT_6_SkipEmptyParts) + p;
                 if (parts.last().contains(QRegExp("^(?:Jr|II|III|IV)$"))) // If otherwise, ignore it
                     last_name += '_' + parts.last();
             }
             else
             {
-                fore_name_parts = author_i.split(' ', QString::SkipEmptyParts);
+                fore_name_parts = author_i.split(' ', _QT_6_SkipEmptyParts);
                 if (fore_name_parts.count() > 0)
                     last_name = fore_name_parts.takeFirst();
             }
@@ -495,7 +495,7 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
         }
         else
         {
-            fore_name_parts = author_i.split(' ', QString::SkipEmptyParts);
+            fore_name_parts = author_i.split(' ', _QT_6_SkipEmptyParts);
             if (fore_name_parts.count() > 0)
                 last_name = fore_name_parts.takeLast();
             c2bUtils::debug("Natural order");
