@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibExtractor.h"
@@ -222,7 +222,7 @@ void bibExtractor::proxyLogMessage() const
 
 void bibExtractor::logMessage(const QString& ms) const
 {
-    cout << "[cb2bib] " << ms << endl;
+    cout << "[cb2bib] " << ms << _QT_6_endl;
 }
 
 bool bibExtractor::isReliable() const
