@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibParser.h"
@@ -116,7 +116,7 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
     else if (field == QLatin1String("keywords"))
     {
         v.replace(" - ", ",");
-        QStringList kl(v.split(QRegExp("[^\\w\\s-']"), QString::SkipEmptyParts));
+        QStringList kl(v.split(QRegExp("[^\\w\\s-']"), _QT_6_SkipEmptyParts));
         kl.removeAll(" ");
         kl.removeDuplicates();
         v = kl.join(", ");
@@ -240,7 +240,7 @@ QString bibParser::excerpt(const QString& text, const QStringList& hints) const
                 " ");
     txt = hints.join(" ") + ' ' + txt;
     txt = c2bUtils::simplifyString(txt);
-    const QStringList txtlist(txt.split(' ', QString::SkipEmptyParts));
+    const QStringList txtlist(txt.split(' ', _QT_6_SkipEmptyParts));
     QStringList txtlistSimp;
     for (int i = 0; i < std::min(15, txtlist.count()); ++i)
         txtlistSimp.append(txtlist.at(i));
@@ -539,7 +539,7 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
             if (!rx.isValid())
                 c2bUtils::warn(tr("RegExp |%1| is not valid").arg(ItemX));
 
-            const QStringList list(fieldset.split(' ', QString::SkipEmptyParts));
+            const QStringList list(fieldset.split(' ', _QT_6_SkipEmptyParts));
             const int efields(list.count());
             const int cfields(rx.captureCount());
             int npos(rx.indexIn(ottext));
@@ -666,7 +666,7 @@ QString bibParser::removeTags(const QString& text) const
 
 QString bibParser::metadataSection(const QString& text, const QString& identifier) const
 {
-    const QStringList lines(text.split(QRegExp("[\\r\\n]"), QString::KeepEmptyParts));
+    const QStringList lines(text.split(QRegExp("[\\r\\n]"), _QT_6_KeepEmptyParts));
     const int nl(lines.count());
     int il(-1);
     int sl(0);
