@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibSearcher.h"
@@ -96,6 +96,8 @@ _          contextual_search                contextual.{0,25}search
 
 -          non-parametric                   non.{0,1}parametr
 
+.          non.parametric                   non.{0,1}parametr
+
 
 Diacritics and Greek letters:
 
@@ -480,8 +482,8 @@ void bibSearcher::setTitleRank(const QString& title)
             pos = pattern.indexIn(title, pos);
             if (pos > -1)
             {
-                pattern.updateScore();
-                pos += pattern.matchedLength();
+                pattern.updateScore(pos);
+                pos += pattern.advanceLength();
             }
         }
         _reference_score += 10 * pattern.matchedScore();
@@ -491,7 +493,7 @@ void bibSearcher::setTitleRank(const QString& title)
 QString bibSearcher::excerpts(const QString& contents)
 {
     const int max_excerpts(25);
-    const int max_unmerged_excerpts(max_excerpts + 100);
+    const int max_unmerged_excerpts(max_excerpts + 2500);
     QMap<int, int> exc_endpos;
 
     for (int i = 0; i < _patterns.count(); ++i)
@@ -513,9 +515,9 @@ QString bibSearcher::excerpts(const QString& contents)
                 if (++n_excerpts > max_unmerged_excerpts)
                     break;
                 if (_do_rank_results)
-                    pattern.updateScore();
+                    pattern.updateScore(pos);
                 exc_endpos.insert(pos, std::max(pos + pattern.matchedLength(), exc_endpos.value(pos)));
-                pos += pattern.matchedLength();
+                pos += pattern.advanceLength();
             }
         }
         if (_do_rank_results)
@@ -618,9 +620,9 @@ QString bibSearcher::highlight(const QString& abstract)
             if (pos > -1)
             {
                 if (_do_rank_results)
-                    pattern.updateScore();
+                    pattern.updateScore(pos);
                 endpos.insert(pos, std::max(pos + pattern.matchedLength(), endpos.value(pos)));
-                pos += pattern.matchedLength();
+                pos += pattern.advanceLength();
             }
         }
         if (_do_rank_results)
