@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionIndex.h"
@@ -28,7 +28,7 @@ static const int _in_long_document_sentence_repetition(3);
 static const int _in_short_document_sentence_repetition(2);
 static const int _inter_document_sentence_repetition(3);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)) && (QT_VERSION < QT_VERSION_CHECK(5, 12, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::UseUnicodePropertiesOption |
         QRegularExpression::OptimizeOnFirstUsageOption);
 #else
@@ -95,7 +95,7 @@ int collectionIndex::index(const QString& dir)
     const QString bibtexdir(dir.isEmpty()
                             ? QDir::toNativeSeparators(QFileInfo(_settingsP->fileName("cb2Bib/BibTeXFile")).path())
                             : QDir::toNativeSeparators(dir));
-    _out << QObject::tr("Indexing references from directory %1...").arg(bibtexdir) << endl;
+    _out << QObject::tr("Indexing references from directory %1...").arg(bibtexdir) << _QT_6_endl;
 
     bibReference reference;
     documentCache dc;
@@ -107,7 +107,7 @@ int collectionIndex::index(const QString& dir)
     if (bibtexfns.count() == 0)
     {
         ++_nerrors;
-        _out << QObject::tr("Error: No BibTeX files at %1").arg(bibtexdir) << endl;
+        _out << QObject::tr("Error: No BibTeX files at %1").arg(bibtexdir) << _QT_6_endl;
         return _nerrors;
     }
 
@@ -119,7 +119,7 @@ int collectionIndex::index(const QString& dir)
     for (int i = 0; i < bibtexfns.count(); ++i)
     {
         const QString bibtexfn(bibtexfns.at(i));
-        _out << QObject::tr("Indexing %1...").arg(bibtexfn) << endl;
+        _out << QObject::tr("Indexing %1...").arg(bibtexfn) << _QT_6_endl;
         const QString bibtex(c2bUtils::fileToString(bibtexfn));
         dc.load(bibtexfn, documentContents::Complete);
 
@@ -147,10 +147,10 @@ int collectionIndex::index(const QString& dir)
     {
         _out << QObject::tr("Warning: %1 documents could not be converted to text. Check search converter is set.")
              .arg(nfailures)
-             << endl;
-        _out << QObject::tr("         Refresh cache by running a prove search including document contents.") << endl;
+             << _QT_6_endl;
+        _out << QObject::tr("         Refresh cache by running a prove search including document contents.") << _QT_6_endl;
     }
-    _out << QObject::tr("done") << endl;
+    _out << QObject::tr("done") << _QT_6_endl;
 
     digestKeySentences();
     cleanupKeySentences();
@@ -161,9 +161,9 @@ int collectionIndex::index(const QString& dir)
     {
         QStringList sentences(_document_sentences.values(i));
         std::sort(sentences.begin(), sentences.end());
-        _out << i << "  " << documents.at(i) << ':' << endl;
+        _out << i << "  " << documents.at(i) << ':' << _QT_6_endl;
         for (int j = 0; j < sentences.count(); ++j)
-            _out << "        " << sentences.at(j) << endl;
+            _out << "        " << sentences.at(j) << _QT_6_endl;
     }
 #endif
 
@@ -172,7 +172,7 @@ int collectionIndex::index(const QString& dir)
     QFile documentslf(QDir::cleanPath(documentslfn));
     if (documentslf.open(QIODevice::WriteOnly))
     {
-        _out << QObject::tr("Writing %1...").arg(documentslfn) << endl;
+        _out << QObject::tr("Writing %1...").arg(documentslfn) << _QT_6_endl;
         QDataStream stream(&documentslf);
         stream << documentfns.count();
         for (int i = 0; i < documentfns.count(); ++i)
@@ -182,13 +182,13 @@ int collectionIndex::index(const QString& dir)
     else
     {
         ++_nerrors;
-        _out << QObject::tr("Error: %1 can not be written").arg(documentslfn) << endl;
+        _out << QObject::tr("Error: %1 can not be written").arg(documentslfn) << _QT_6_endl;
     }
     const QString documentsifn(QDir::toNativeSeparators(cache_dir + "/documents.ic2b"));
     QFile documentsif(documentsifn);
     if (documentsif.open(QIODevice::WriteOnly))
     {
-        _out << QObject::tr("Writing %1...").arg(documentsifn) << endl;
+        _out << QObject::tr("Writing %1...").arg(documentsifn) << _QT_6_endl;
         QDataStream stream(&documentsif);
         for (int i = 0; i < documents.count(); ++i)
         {
@@ -203,12 +203,12 @@ int collectionIndex::index(const QString& dir)
     else
     {
         ++_nerrors;
-        _out << QObject::tr("Error: %1 can not be written").arg(documentsifn) << endl;
+        _out << QObject::tr("Error: %1 can not be written").arg(documentsifn) << _QT_6_endl;
     }
 
-    _out << QObject::tr("done") << endl;
+    _out << QObject::tr("done") << _QT_6_endl;
     const double time = double(clock() - start_time) / double(CLOCKS_PER_SEC);
-    _out << QObject::tr("Indexing CPU time: %1s").arg(time) << endl;
+    _out << QObject::tr("Indexing CPU time: %1s").arg(time) << _QT_6_endl;
 
     return _nerrors;
 }
@@ -242,13 +242,13 @@ void collectionIndex::setKeySentences(const int documentid, const QString& text)
 
 void collectionIndex::analyzeKeySentences()
 {
-    _out << QObject::tr("Analysing keyword sentences...") << endl;
+    _out << QObject::tr("Analysing keyword sentences...") << _QT_6_endl;
 
     posTagger pt;
     if (!pt.loadLexicon())
     {
         ++_nerrors;
-        _out << QObject::tr("Error: cb2Bib POS lexicon could not be loaded; check Configure Files") << endl;
+        _out << QObject::tr("Error: cb2Bib POS lexicon could not be loaded; check Configure Files") << _QT_6_endl;
         return;
     }
     QStringList validlist;
@@ -282,7 +282,7 @@ void collectionIndex::analyzeKeySentences()
     QFile sentenceslf(sentenceslfn);
     if (sentenceslf.open(QIODevice::WriteOnly))
     {
-        _out << QObject::tr("Writing %1...").arg(sentenceslfn) << endl;
+        _out << QObject::tr("Writing %1...").arg(sentenceslfn) << _QT_6_endl;
         QDataStream stream(&sentenceslf);
         stream << validlist.count();
         const QChar hs('-');
@@ -300,13 +300,13 @@ void collectionIndex::analyzeKeySentences()
     else
     {
         ++_nerrors;
-        _out << QObject::tr("Error: %1 can not be written").arg(sentenceslfn) << endl;
+        _out << QObject::tr("Error: %1 can not be written").arg(sentenceslfn) << _QT_6_endl;
     }
     const QString sentencesifn(QDir::toNativeSeparators(QDir::cleanPath(cache_dir + "/sentences.ic2b")));
     QFile sentencesif(sentencesifn);
     if (sentencesif.open(QIODevice::WriteOnly))
     {
-        _out << QObject::tr("Writing %1...").arg(sentencesifn) << endl;
+        _out << QObject::tr("Writing %1...").arg(sentencesifn) << _QT_6_endl;
         QDataStream stream(&sentencesif);
         for (int i = 0; i < validlist.count(); ++i)
         {
@@ -323,7 +323,7 @@ void collectionIndex::analyzeKeySentences()
     else
     {
         ++_nerrors;
-        _out << QObject::tr("Error: %1 can not be written").arg(sentencesifn) << endl;
+        _out << QObject::tr("Error: %1 can not be written").arg(sentencesifn) << _QT_6_endl;
     }
 #ifdef C2B_TRACE_MEMORY
     qDebug() << "After writing sentencesifn:";
@@ -348,17 +348,17 @@ void collectionIndex::analyzeKeySentences()
     else
     {
         ++_nerrors;
-        _out << QObject::tr("Error: %1 can not be written").arg(documentsifn) << endl;
+        _out << QObject::tr("Error: %1 can not be written").arg(documentsifn) << _QT_6_endl;
     }
 
-    _out << QObject::tr("Raw keyword sentences: ") << _keysentences.size() << endl;
-    _out << QObject::tr("Keyword sentences: ") << validlist.count() << endl;
-    _out << QObject::tr("done") << endl;
+    _out << QObject::tr("Raw keyword sentences: ") << _keysentences.size() << _QT_6_endl;
+    _out << QObject::tr("Keyword sentences: ") << validlist.count() << _QT_6_endl;
+    _out << QObject::tr("done") << _QT_6_endl;
 #if !C2B_DEBUG_COLLECTIONINDEX
-    _out << QObject::tr("Clearing arrays...") << endl;
+    _out << QObject::tr("Clearing arrays...") << _QT_6_endl;
     _keysentences.clear();
     _document_sentences.clear();
-    _out << QObject::tr("done") << endl;
+    _out << QObject::tr("done") << _QT_6_endl;
 #endif
 #ifdef C2B_TRACE_MEMORY
     qDebug() << "After clearing arrays:";
@@ -378,7 +378,7 @@ void collectionIndex::analyzeKeySentences()
     else
     {
         ++_nerrors;
-        _out << QObject::tr("Error: %1 can not be read").arg(documentsifn) << endl;
+        _out << QObject::tr("Error: %1 can not be read").arg(documentsifn) << _QT_6_endl;
     }
 #ifdef C2B_TRACE_MEMORY
     qDebug() << "After inserting _document_sentenceids:";
@@ -387,13 +387,13 @@ void collectionIndex::analyzeKeySentences()
 #if C2B_DEBUG_COLLECTIONINDEX
     std::sort(taggedvalidlist.begin(), taggedvalidlist.end());
     for (int i = 0; i < taggedvalidlist.count(); ++i)
-        _out << taggedvalidlist.at(i) << endl;
+        _out << taggedvalidlist.at(i) << _QT_6_endl;
 #endif
 }
 
 void collectionIndex::cleanupKeySentences()
 {
-    _out << QObject::tr("Cleaning keyword sentences...") << endl;
+    _out << QObject::tr("Cleaning keyword sentences...") << _QT_6_endl;
 
     QStringList keysentenceskeys;
     for (QMap<QString, KeysentenceData>::const_iterator si = _keysentences.constBegin(); si != _keysentences.constEnd();
@@ -423,12 +423,12 @@ void collectionIndex::cleanupKeySentences()
         if (sj.endsWith(si) && _keysentences.value(si).ndocuments == _keysentences.value(sj).ndocuments)
             _keysentences[si].ndocuments = 0;
     }
-    _out << QObject::tr("done") << endl;
+    _out << QObject::tr("done") << _QT_6_endl;
 }
 
 void collectionIndex::digestKeySentences()
 {
-    _out << QObject::tr("Digesting keyword sentences...") << endl;
+    _out << QObject::tr("Digesting keyword sentences...") << _QT_6_endl;
 
     const QChar hyphen('_');
 
@@ -477,35 +477,35 @@ void collectionIndex::digestKeySentences()
         // Unify simple coordinations
         if (s.count(coordination_and) == 1)
         {
-            const QStringList p(s.split(coordination_and, QString::SkipEmptyParts));
+            const QStringList p(s.split(coordination_and, _QT_6_SkipEmptyParts));
             const QString sp(p.at(1) + coordination_and + p.at(0));
             if (_keysentences.contains(sp))
                 ksdndmax = _digest_sentence(&_keysentences[sp], ksdndmax, &ndmax);
         }
         else if (s.count(coordination_or) == 1)
         {
-            const QStringList p(s.split(coordination_or, QString::SkipEmptyParts));
+            const QStringList p(s.split(coordination_or, _QT_6_SkipEmptyParts));
             const QString sp(p.at(1) + coordination_or + p.at(0));
             if (_keysentences.contains(sp))
                 ksdndmax = _digest_sentence(&_keysentences[sp], ksdndmax, &ndmax);
         }
         else if (s.count(coordination_of) == 1)
         {
-            const QStringList p(s.split(coordination_of, QString::SkipEmptyParts));
+            const QStringList p(s.split(coordination_of, _QT_6_SkipEmptyParts));
             const QString sp(p.at(1) + _space_char + p.at(0));
             if (_keysentences.contains(sp))
                 ksdndmax = _digest_sentence(&_keysentences[sp], ksdndmax, &ndmax);
         }
         else if (s.count(coordination_on) == 1)
         {
-            const QStringList p(s.split(coordination_on, QString::SkipEmptyParts));
+            const QStringList p(s.split(coordination_on, _QT_6_SkipEmptyParts));
             const QString sp(p.at(1) + _space_char + p.at(0));
             if (_keysentences.contains(sp))
                 ksdndmax = _digest_sentence(&_keysentences[sp], ksdndmax, &ndmax);
         }
         else if (s.count(coordination_in) == 1)
         {
-            const QStringList p(s.split(coordination_in, QString::SkipEmptyParts));
+            const QStringList p(s.split(coordination_in, _QT_6_SkipEmptyParts));
             const QString sp(p.at(1) + _space_char + p.at(0));
             if (_keysentences.contains(sp))
                 ksdndmax = _digest_sentence(&_keysentences[sp], ksdndmax, &ndmax);
@@ -543,7 +543,7 @@ void collectionIndex::digestKeySentences()
         ksdndmax->ndocuments = ksdndmax->documents.count();
     }
 
-    _out << QObject::tr("done") << endl;
+    _out << QObject::tr("done") << _QT_6_endl;
 }
 
 collectionIndex::KeysentenceData* collectionIndex::_digest_sentence(KeysentenceData* ksd, KeysentenceData* ksdndmax,
