@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "document.h"
@@ -48,7 +48,7 @@ QString document::toString()
     }
 
     QProcess converter;
-    QStringList args(_converter_arg.split(' ', QString::SkipEmptyParts));
+    QStringList args(_converter_arg.split(' ', _QT_6_SkipEmptyParts));
     args.append(_document_fn);
     args.append(_converter_output);
     converter.start(_converter_bin, args);
