@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -45,7 +45,7 @@ heuristicBibParser::heuristicBibParser(bibParser* bp)
     // P. Constans. A Simple Extraction Procedure for Bibliographical Author Field.
     // arXiv:0902.0755, 2009.
     _word_prefix_lexicon =
-        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, QString::SkipEmptyParts);
+        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
     for (int i = 0; i < _word_prefix_lexicon.count(); ++i)
     {
         _word_prefix_lexicon[i].replace('_', ' ');
@@ -602,7 +602,7 @@ void heuristicBibParser::guessPages(const QString& text)
             if (!rxH.cap(1).startsWith('0'))
             {
                 const QString pp(_bpP->parse(_pages, QString("%1 %2").arg(rxH.cap(1), rxH.cap(2))));
-                const QStringList flpp(pp.split(QRegExp("\\D"), QString::SkipEmptyParts));
+                const QStringList flpp(pp.split(QRegExp("\\D"), _QT_6_SkipEmptyParts));
                 if (flpp.count() != 2)
                     continue;
                 const int fp(flpp.first().toInt());
