@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Improvements and modifications:
@@ -245,7 +245,7 @@ void idMaker::make_title_first_word(QString* id)
 {
     if (_title.contains(c2bUtils::nonAsciiLetter))
         _title = c2bUtils::toAscii(_title, c2bUtils::FromBibTeX);
-    const QStringList ws(_title.toLower().split(c2bUtils::nonAsciiLetter, QString::SkipEmptyParts));
+    const QStringList ws(_title.toLower().split(c2bUtils::nonAsciiLetter, _QT_6_SkipEmptyParts));
     _title.resize(0);
     for (int w = 0; w < ws.count(); ++w)
         if (ws.at(w).length() > 2 && ws.at(w) != QLatin1String("are") && ws.at(w) != QLatin1String("the"))
