@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "journalDB.h"
@@ -38,20 +38,20 @@ journalDB::journalDB(const QString& dbfile)
         ++line_number;
         if (line.isEmpty() || line.startsWith('#'))
             continue;
-        const QStringList spLine(line.split('|', QString::SkipEmptyParts));
+        const QStringList spLine(line.split('|', _QT_6_SkipEmptyParts));
         if (spLine.count() != 3)
         {
             c2bUtils::warn(QObject::tr("Syntax error in journal file at line %1").arg(line_number));
             continue;
         }
-        const QStringList spAbbreviated(spLine.at(1).split('=', QString::SkipEmptyParts));
+        const QStringList spAbbreviated(spLine.at(1).split('=', _QT_6_SkipEmptyParts));
         const int na(spAbbreviated.count());
         if (na < 1 || na > 2)
         {
             c2bUtils::warn(QObject::tr("Syntax error in journal file at line %1").arg(line_number));
             continue;
         }
-        const QStringList spExtended(spLine.at(2).split('=', QString::SkipEmptyParts));
+        const QStringList spExtended(spLine.at(2).split('=', _QT_6_SkipEmptyParts));
         const int ne(spExtended.count());
         if (ne < 1 || ne > 2)
         {
