@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef METADATAPARSER_H
@@ -55,7 +55,7 @@ private:
 
     inline QString formattedAuthor(const QString& author) const
     {
-        const QStringList alist(author.split(" and ", QString::SkipEmptyParts));
+        const QStringList alist(author.split(" and ", _QT_6_SkipEmptyParts));
         int na(alist.count());
         if (na <= 2)
             return author;
