@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "network.h"
@@ -198,12 +198,12 @@ void network::_fetch_client(const Action action)
     if (act == Copy)
     {
         fmclient_bin = FmClientCopyBin;
-        arglist = FmClientCopyArg.split(' ', QString::SkipEmptyParts);
+        arglist = FmClientCopyArg.split(' ', _QT_6_SkipEmptyParts);
     }
     else if (act == Move)
     {
         fmclient_bin = FmClientMoveBin;
-        arglist = FmClientMoveArg.split(' ', QString::SkipEmptyParts);
+        arglist = FmClientMoveArg.split(' ', _QT_6_SkipEmptyParts);
     }
     arglist.append(_source_filename);
     arglist.append(_destination_filename);
