@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef NETWORK_H
@@ -58,6 +58,11 @@ public:
         return _file_mimetype_string;
     }
 
+    inline const QStringList supportedSchemes() const
+    {
+        return _fetcher->supportedSchemes();
+    }
+
     static inline Action actionType(const QString& action)
     {
         return action == "move" ? Move : Copy;
