@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "networkQuery.h"
@@ -38,6 +38,11 @@ void networkQuery::init()
     _timing = QDateTime::currentDateTime();
 }
 
+bool networkQuery::hasSsl()
+{
+    return _networkP->supportedSchemes().contains("https");
+}
+
 void networkQuery::submitQuery(const bibReference& reference, const QString& raw_reference, const bool check_document)
 {
     // Submission Initialization
