@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "posTagger.h"
@@ -82,7 +82,7 @@ bool posTagger::loadLexicon()
 
 QString posTagger::tagged(const QString& text) const
 {
-    const QStringList words(text.split(_space, QString::SkipEmptyParts));
+    const QStringList words(text.split(_space, _QT_6_SkipEmptyParts));
     const int nw(words.count());
     QString t(_period);
     for (int i = 0; i < nw; ++i)
