@@ -1,11 +1,12 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "searchPattern.h"
 
+#include "multipatternLengths.h"
 #include "triads.h"
 
 #include <QMap>
@@ -15,7 +16,7 @@
 #define __has_cpp_attribute(name) 0
 #endif
 #if __has_cpp_attribute(fallthrough)
-#define FALLTHROUGH [[fallthrough]]
+#define FALLTHROUGH __attribute__((fallthrough))
 #else
 #define FALLTHROUGH
 #endif
@@ -95,11 +96,11 @@ const QMap<QString, searchPattern::Type> searchPattern::typemap()
 
 
 searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::CaseSensitivity cs)
-    : csensitivity(cs), type(t), length(-1)
+    : csensitivity(cs), type(t), alength(-1), mlength(-1), slength(-1)
 {
-    _set_typed_pattern(pattern);
+    const int plength(_set_typed_pattern(pattern));
 
-    switch (t)
+    switch (type)
     {
     default:
         c2bUtils::warn(QObject::tr("Internal Error: Invalid search pattern type. Set to 'Approximate string'"));
@@ -154,7 +155,7 @@ searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::
     break;
     case RegularExpression:
     {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)) && (QT_VERSION < QT_VERSION_CHECK(5, 12, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
         const QRegularExpression::PatternOptions po(QRegularExpression::DontCaptureOption |
                 QRegularExpression::UseUnicodePropertiesOption |
                 QRegularExpression::OptimizeOnFirstUsageOption);
@@ -168,7 +169,7 @@ searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::
     break;
     case Wildcard:
     {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)) && (QT_VERSION < QT_VERSION_CHECK(5, 12, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
         const QRegularExpression::PatternOptions po(
             QRegularExpression::InvertedGreedinessOption | QRegularExpression::DontCaptureOption |
             QRegularExpression::UseUnicodePropertiesOption | QRegularExpression::OptimizeOnFirstUsageOption);
@@ -183,11 +184,34 @@ searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::
     }
     break;
     }
+
+    switch (type)
+    {
+    case Context:
+        mscorer.setPattern(cstemexp.patternLengths());
+        break;
+    case FixedStringContext:
+    {
+        const bool hasdot(typedpattern.contains(QLatin1Char('.')));
+        const int nblanks(typedpattern.count(QLatin1Char(' ')));
+        mscorer.setPattern(multipatternLengths::scorerLengths(plength, nblanks, hasdot));
+    }
+    break;
+    default:
+        mscorer.setPattern(plength);
+        break;
+    }
+
+#ifdef C2B_DEBUG_SEARCHING
+    qDebug() << "searchPattern::matcher::mscorer pattern lengths         " << mscorer.plengths;
+#endif
 }
 
 bool searchPattern::matcher::match(const QString& contents) const
 {
-    length = -1;
+    alength = -1;
+    mlength = -1;
+    slength = -1;
     switch (type)
     {
     case ApproximateString:
@@ -208,7 +232,9 @@ bool searchPattern::matcher::match(const QString& contents) const
 
 bool searchPattern::matcher::match(const documentContents& contents) const
 {
-    length = -1;
+    alength = -1;
+    mlength = -1;
+    slength = -1;
     switch (type)
     {
     case ApproximateString:
@@ -228,6 +254,25 @@ bool searchPattern::matcher::match(const documentContents& contents) const
     }
 }
 
+/**
+   Context Matching
+
+   There are ambiguities for a pattern |w1 w2| when matching a text being for
+   instance either |...w1...w1 w2...| or |...w2...w1 w2...| with operators
+   Context and FixedStringContext. Typical leftmost-longest-rule operators
+   would match |w1...w1 w2| and |w2...w1|, respectively, while on text search
+   usage the alternate match |w1 w2| is preferred because it is closer to the
+   user supplied pattern.
+
+   Since document ranking is based on the closeness pattern-match, the
+   following function defines the advance length for Context and
+   FixedStringContext as two chars instead of the full matched length. This is,
+   match overlapping is permitted, and the match |w1 w2| will be obtained if
+   present.
+
+   In addition, excerpts are in this way closer to expectation.
+
+*/
 int searchPattern::matcher::index(const QString& contents, const int from) const
 {
     int i;
@@ -235,34 +280,46 @@ int searchPattern::matcher::index(const QString& contents, const int from) const
     {
     case ApproximateString:
         i = appexp.indexIn(contents, from);
-        length = appexp.matchedLength();
+        mlength = appexp.matchedLength();
+        alength = mlength;
+        slength = mlength;
         return i;
     case Context:
         i = cstemexp.indexIn(contents, from);
-        length = cstemexp.matchedLength();
+        mlength = cstemexp.matchedLength();
+        alength = std::min(2, mlength);
+        slength = cstemexp.stemmedLength();
         return i;
     case FixedStringAnyWord:
     case FixedStringAllWords:
         i = wordexp.indexIn(contents, from);
-        length = wordexp.matchedLength();
+        mlength = wordexp.matchedLength();
+        alength = mlength;
+        slength = mlength;
         return i;
     case FixedStringContext:
         i = cwordexp.indexIn(contents, from);
-        length = cwordexp.matchedLength();
+        mlength = cwordexp.matchedLength();
+        alength = std::min(2, mlength);
+        slength = mlength;
         return i;
     case FixedString:
         i = strexp.indexIn(contents, from);
-        length = strexp.pattern().length();
+        mlength = strexp.pattern().length();
+        alength = mlength;
+        slength = mlength;
         return i;
     default:
         regexp_match = regexp.match(contents, from);
         i = regexp_match.capturedStart();
-        length = regexp_match.capturedLength();
+        mlength = regexp_match.capturedLength();
+        alength = mlength;
+        slength = mlength;
         return i;
     }
 }
 
-void searchPattern::matcher::_set_typed_pattern(const QString& pattern)
+int searchPattern::matcher::_set_typed_pattern(const QString& pattern)
 {
     const QRegExp rmors("\\|[^\\s]*");
     const QRegExp rmnws("[\\W_]");
@@ -290,7 +347,7 @@ void searchPattern::matcher::_set_typed_pattern(const QString& pattern)
         break;
     }
     stripped = stripped.simplified();
-    plength = type == FixedStringAllWords || type == FixedStringAnyWord ? 0 : stripped.length();
+    const int plength(type == FixedStringAllWords || type == FixedStringAnyWord ? 0 : stripped.length());
 
     switch (type)
     {
@@ -304,11 +361,14 @@ void searchPattern::matcher::_set_typed_pattern(const QString& pattern)
         typedpattern = stripped;
         break;
     }
+
 #ifdef C2B_DEBUG_SEARCHING
     qDebug() << "searchPattern::matcher::_set_typed_pattern pattern      " << pattern << pattern.length();
     qDebug() << "searchPattern::matcher::_set_typed_pattern stripped     " << stripped << stripped.length() << plength;
     qDebug() << "searchPattern::matcher::_set_typed_pattern typedpattern " << typedpattern << typedpattern.length();
 #endif
+
+    return plength;
 }
 
 QString searchPattern::matcher::_wildcard_escaped(const QString& pattern)
