@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SEARCHPATTERN_H
@@ -68,25 +68,29 @@ public:
     {
         return _matcher.index(contents.text(), from);
     }
+    inline int advanceLength() const
+    {
+        return _matcher.alength;
+    }
     inline int matchedLength() const
     {
-        return _matcher.length;
+        return _matcher.mlength;
     }
     inline void initializeScores() const
     {
-        _scorer.initialize();
+        _matcher.mscorer.initialize();
     }
-    inline void updateScore() const
+    inline void updateScore(const int pos) const
     {
-        _scorer.update(_matcher.plength, _matcher.length);
+        _matcher.mscorer.update(pos, _matcher.slength);
     }
     inline int matchedCounter() const
     {
-        return _scorer.nscores;
+        return _matcher.mscorer.nscores;
     }
     inline double matchedScore() const
     {
-        return _scorer.score();
+        return _matcher.mscorer.score();
     }
     inline const QString toString() const
     {
@@ -111,9 +115,11 @@ private:
         Qt::CaseSensitivity csensitivity;
         Type type;
         approximatePattern appexp;
-        int plength;
         mutable QRegularExpressionMatch regexp_match;
-        mutable int length;
+        mutable int alength;
+        mutable int mlength;
+        mutable int slength;
+        mutable scorer mscorer;
         stemMatcher cstemexp;
         wordMatcher cwordexp;
         wordPattern wordexp;
@@ -123,7 +129,7 @@ private:
         int index(const QString& contents, const int from) const;
 
         static QString _wildcard_escaped(const QString& pattern);
-        void _set_typed_pattern(const QString& pattern);
+        int _set_typed_pattern(const QString& pattern);
 
         static inline bool _match_signature(const QString& ps, const QString& cs)
         {
@@ -195,7 +201,6 @@ private:
     int _rank;
     matcher _matcher;
     modifiers _modifier;
-    mutable scorer _scorer;
 };
 
 #endif
