@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "substringMatcher.h"
@@ -16,7 +16,7 @@ substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensiti
     : _hook(-1), _matched_length(-1), _p0(0), _pn(0)
 {
     QRegExp sep("\\.\\{(\\d+),(\\d+)\\}");
-    QStringList substrings(pattern.split(sep, QString::SkipEmptyParts));
+    QStringList substrings(pattern.split(sep, _QT_6_SkipEmptyParts));
     Q_ASSERT_X(substrings.count() >= 2, "substringMatcher", "Expected at least two substrings in pattern");
     int s(0);
     QList<int> stretches;
