@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -164,7 +164,7 @@ void texToHtml::parseElement(const QString& p, const QString& e, const QString&
         _title = toHtmlString(v);
     else if (e == "itemize")
     {
-        const QStringList items(v.trimmed().split("\\item ", QString::SkipEmptyParts));
+        const QStringList items(v.trimmed().split("\\item ", _QT_6_SkipEmptyParts));
         for (int i = 0; i < items.count(); ++i)
             parseTextParagraph("- " + items.at(i).simplified());
     }
@@ -236,7 +236,7 @@ void texToHtml::extractCites(const QString& p)
         QString cites;
         if (c2bUtils::inBraces(pos + 6, p, &cites))
         {
-            const QStringList cite(cites.split(',', QString::SkipEmptyParts));
+            const QStringList cite(cites.split(',', _QT_6_SkipEmptyParts));
             for (int i = 0; i < cite.count(); ++i)
             {
                 const QString c(cite.at(i).trimmed());
