@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "triads.h"
@@ -51,7 +51,11 @@ const QString triads::asciiTextSignature(const QString& str)
         if (!triads.contains(code))
             triads.insert(code);
     }
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    QList<int> codes(triads.values());
+#else
     QList<int> codes(triads.toList());
+#endif
     std::sort(codes.begin(), codes.end());
     s.resize(codes.count());
     for (int i = 0; i < codes.count(); ++i)
