@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterModel.h"
@@ -125,7 +125,7 @@ void c2bCiterModel::setPatternFilter(const QString& pattern, QModelIndex* curren
 {
     _history.saveCurrentState(_format, _filter, _current_item(current_index), current_index, _fstring);
     emit layoutAboutToBeChanged();
-    const QStringList word(pattern.split(c2bUtils::nonLetter, QString::SkipEmptyParts));
+    const QStringList word(pattern.split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
     _filter = word.count() > 0 ? c2bCiter::Pattern : c2bCiter::None;
     _format = format;
     if (_filter == c2bCiter::Pattern)
@@ -600,7 +600,11 @@ void c2bCiterModel::_add_citations(const QString& fn)
         uint included_date;
         const QFileInfo finf(file);
         if (finf.exists())
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+            included_date = finf.lastModified().date().startOfDay().toTime_t();
+#else
             included_date = QDateTime(finf.lastModified().date()).toTime_t();
+#endif
         else
             included_date = 0;
 
@@ -676,7 +680,7 @@ void c2bCiterModel::_set_table_data()
     int ij(0);
     for (int i = 0; i < _citation_count; ++i)
     {
-        const QStringList authors(_author_string.at(i).split(sep, QString::KeepEmptyParts));
+        const QStringList authors(_author_string.at(i).split(sep, _QT_6_KeepEmptyParts));
         for (int j = 0; j < authors.count(); ++j)
         {
             _author[ij] = authors.at(j).trimmed();
