@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPostprocess.h"
@@ -69,7 +69,7 @@ c2bPostprocess::~c2bPostprocess()
 void c2bPostprocess::PProcessFile()
 {
     // Postprocessing BibTeX
-    const QStringList arglist(PPBIBTEX_ARG.split(' ', QString::SkipEmptyParts));
+    const QStringList arglist(PPBIBTEX_ARG.split(' ', _QT_6_SkipEmptyParts));
     QStringList args;
     for (int i = 0; i < arglist.count(); i++)
     {
