@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSaveRegExp.h"
@@ -133,7 +133,7 @@ void c2bSaveRegExp::setInformation()
 {
     QString info;
     bool can_save(false);
-    const QStringList field_list(ui.Fields->text().split(' ', QString::SkipEmptyParts));
+    const QStringList field_list(ui.Fields->text().split(' ', _QT_6_SkipEmptyParts));
     const int fields(field_list.count());
     _pattern_rx.setPattern(ui.RegExp->text());
     const int captures(_pattern_rx.captureCount());
