@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -27,18 +27,18 @@ c2bTests::c2bTests() : cout(*(new QTextStream(stdout))), _failed_test_count(0),
 {
     cout.setCodec("UTF-8");
 
-    cout << "============" << endl;
-    cout << "cb2Bib tests" << endl;
-    cout << "============" << endl;
+    cout << "============" << _QT_6_endl;
+    cout << "cb2Bib tests" << _QT_6_endl;
+    cout << "============" << _QT_6_endl;
     _bibliographic_dir = QFileInfo(settings::instance()->fileName("cb2Bib/BibTeXFile")).absolutePath();
 }
 
 c2bTests::~c2bTests()
 {
-    cout << endl;
-    cout << "=================" << endl;
-    cout << "cb2Bib tests done" << endl;
-    cout << "=================" << endl << endl;
+    cout << _QT_6_endl;
+    cout << "=================" << _QT_6_endl;
+    cout << "cb2Bib tests done" << _QT_6_endl;
+    cout << "=================" << _QT_6_endl << _QT_6_endl;
     delete &cout;
 }
 
@@ -63,8 +63,8 @@ int c2bTests::allTests()
     compression_check();
     write_information();
 #endif
-    cout << endl << endl;
-    cout << "Tests done. Tests: " << _test_count << " Failed: " << _failed_test_count << endl;
+    cout << _QT_6_endl << _QT_6_endl;
+    cout << "Tests done. Tests: " << _test_count << " Failed: " << _failed_test_count << _QT_6_endl;
     return 0;
 }
 
@@ -91,18 +91,18 @@ void c2bTests::compression_check()
     test += QChar(10);
     QByteArray ba = test.toUtf8();
     bool passed(c2bUtils::fromUtf8(ba) == QString::fromUtf8(ba));
-    cout << endl;
+    cout << _QT_6_endl;
     if (passed)
     {
-        cout << "-----------------------------------------------------------------" << endl;
-        cout << "Check for c2b utf8: passed" << endl;
-        cout << "-----------------------------------------------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
+        cout << "Check for c2b utf8: passed" << _QT_6_endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
     }
     else
     {
-        cout << "-----------------------------------------------------------------" << endl;
-        cout << "WARNING: Check for c2b utf8 FAILED! Please report it as a bug" << endl;
-        cout << "-----------------------------------------------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
+        cout << "WARNING: Check for c2b utf8 FAILED! Please report it as a bug" << _QT_6_endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
         ++_failed_test_count;
     }
     ++_test_count;
@@ -114,15 +114,15 @@ void c2bTests::compression_check()
     passed = (dcs == test) && (test.toUtf8().length() > cba.length()) && (dcs.utf16()[dcs.size()] == 0);
     if (passed)
     {
-        cout << "-----------------------------------------------------------------" << endl;
-        cout << "Check for compression: passed" << endl;
-        cout << "-----------------------------------------------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
+        cout << "Check for compression: passed" << _QT_6_endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
     }
     else
     {
-        cout << "-----------------------------------------------------------------" << endl;
-        cout << "WARNING: Check for compression FAILED! Please report it as a bug" << endl;
-        cout << "-----------------------------------------------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
+        cout << "WARNING: Check for compression FAILED! Please report it as a bug" << _QT_6_endl;
+        cout << "-----------------------------------------------------------------" << _QT_6_endl;
         ++_failed_test_count;
     }
     ++_test_count;
@@ -130,79 +130,79 @@ void c2bTests::compression_check()
 
 void c2bTests::write_information()
 {
-    cout << endl;
-    cout << "-------------------------" << endl;
-    cout << "Miscellaneous information" << endl;
-    cout << "-------------------------" << endl;
-    cout << endl;
-    cout << "Version: cb2bib " << C2B_VERSION << endl;
+    cout << _QT_6_endl;
+    cout << "-------------------------" << _QT_6_endl;
+    cout << "Miscellaneous information" << _QT_6_endl;
+    cout << "-------------------------" << _QT_6_endl;
+    cout << _QT_6_endl;
+    cout << "Version: cb2bib " << C2B_VERSION << _QT_6_endl;
 #if defined(C2B_USE_LZSSE)
-    cout << "Compression: lzsse" << endl;
+    cout << "Compression: lzsse" << _QT_6_endl;
 #elif defined(C2B_USE_LZ4)
-    cout << "Compression: lz4" << endl;
+    cout << "Compression: lz4" << _QT_6_endl;
 #elif defined(C2B_USE_LZO)
-    cout << "Compression: lzo2" << endl;
+    cout << "Compression: lzo2" << _QT_6_endl;
 #else
-    cout << "Compression: zlib" << endl;
+    cout << "Compression: zlib" << _QT_6_endl;
 #endif
 #if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
-    cout << "Optimized PCRE: yes" << endl;
+    cout << "Optimized PCRE: yes" << _QT_6_endl;
 #else
-    cout << "Optimized PCRE: no" << endl;
+    cout << "Optimized PCRE: no" << _QT_6_endl;
 #endif
 #ifdef C2B_USE_TXTMATCHER_AVX2
-    cout << "Optimized txtmatcher: AVX2" << endl;
+    cout << "Optimized txtmatcher: AVX2" << _QT_6_endl;
 #endif
 #ifdef C2B_USE_TXTMATCHER_SSE2
-    cout << "Optimized txtmatcher: SSE2" << endl;
+    cout << "Optimized txtmatcher: SSE2" << _QT_6_endl;
 #endif
 #ifdef C2B_USE_TXTMATCHER_SCALAR
-    cout << "Optimized txtmatcher: no" << endl;
+    cout << "Optimized txtmatcher: no" << _QT_6_endl;
 #endif
 #ifdef C2B_USE_QWEBKIT
-    cout << "Compiled against QtWebKit: yes" << endl;
+    cout << "Compiled against QtWebKit: yes" << _QT_6_endl;
 #else
-    cout << "Compiled against QtWebKit: no" << endl;
+    cout << "Compiled against QtWebKit: no" << _QT_6_endl;
 #endif
 #ifdef C2B_USE_QWEBENGINE
-    cout << "Compiled against QtWebEngine: yes" << endl;
+    cout << "Compiled against QtWebEngine: yes" << _QT_6_endl;
 #else
-    cout << "Compiled against QtWebEngine: no" << endl;
+    cout << "Compiled against QtWebEngine: no" << _QT_6_endl;
 #endif
 #ifdef C2B_USE_CBPOLL
-    cout << "Clipboard polling: yes" << endl;
+    cout << "Clipboard polling: yes" << _QT_6_endl;
 #else
-    cout << "Clipboard polling: no" << endl;
+    cout << "Clipboard polling: no" << _QT_6_endl;
 #endif
-    cout << "Application binary path: " << QCoreApplication::instance()->applicationDirPath() << endl;
-    cout << "Application hardcoded data path: " << C2B_DATA_DIR << endl;
+    cout << "Application binary path: " << QCoreApplication::instance()->applicationDirPath() << _QT_6_endl;
+    cout << "Application hardcoded data path: " << C2B_DATA_DIR << _QT_6_endl;
 #ifdef Q_OS_MACOS
     QString C2B_DATA_DIR_MAC(C2B_DATA_DIR);
     if (QDir(C2B_DATA_DIR + "/data/").exists())
         C2B_DATA_DIR_MAC = QDir::cleanPath(C2B_DATA_DIR + '/');
     else if (QDir(QCoreApplication::instance()->applicationDirPath() + "/../Resources/data/").exists())
         C2B_DATA_DIR_MAC = QDir::cleanPath(QCoreApplication::instance()->applicationDirPath() + "/../Resources/");
-    cout << "Application macosx data path: " << C2B_DATA_DIR_MAC << endl;
+    cout << "Application macosx data path: " << C2B_DATA_DIR_MAC << _QT_6_endl;
 #endif
-    cout << "\n-------------------------" << endl;
-    cout << "OS:" << endl;
-    cout << "Build CPU:       " << QSysInfo::buildCpuArchitecture() << endl;
-    cout << "CPU:             " << QSysInfo::currentCpuArchitecture() << endl;
-    cout << "Kernel Type:     " << QSysInfo::kernelType() << endl;
-    cout << "Kernel Version:  " << QSysInfo::kernelVersion() << endl;
-    cout << "Product Type:    " << QSysInfo::productType() << endl;
-    cout << "Product Version: " << QSysInfo::productVersion() << '|' << int(QSysInfo::productVersion().toDouble()) << endl;
-    cout << "Name:            " << QSysInfo::prettyProductName() << endl;
-    cout << "-------------------------" << endl;
-    cout << endl;
+    cout << "\n-------------------------" << _QT_6_endl;
+    cout << "OS:" << _QT_6_endl;
+    cout << "Build CPU:       " << QSysInfo::buildCpuArchitecture() << _QT_6_endl;
+    cout << "CPU:             " << QSysInfo::currentCpuArchitecture() << _QT_6_endl;
+    cout << "Kernel Type:     " << QSysInfo::kernelType() << _QT_6_endl;
+    cout << "Kernel Version:  " << QSysInfo::kernelVersion() << _QT_6_endl;
+    cout << "Product Type:    " << QSysInfo::productType() << _QT_6_endl;
+    cout << "Product Version: " << QSysInfo::productVersion() << '|' << int(QSysInfo::productVersion().toDouble()) << _QT_6_endl;
+    cout << "Name:            " << QSysInfo::prettyProductName() << _QT_6_endl;
+    cout << "-------------------------" << _QT_6_endl;
+    cout << _QT_6_endl;
 }
 
 void c2bTests::heuristic_author()
 {
-    cout << endl;
-    cout << "---------------------------------" << endl;
-    cout << "Test heuristic author recognition" << endl;
-    cout << "---------------------------------" << endl;
+    cout << _QT_6_endl;
+    cout << "---------------------------------" << _QT_6_endl;
+    cout << "Test heuristic author recognition" << _QT_6_endl;
+    cout << "---------------------------------" << _QT_6_endl;
 
     QFileInfoList flist = QDir(_bibliographic_dir).entryInfoList(QStringList() << "*.bib");
     bibParser bp;
@@ -217,7 +217,7 @@ void c2bTests::heuristic_author()
     {
         const QString bib_file(flist.at(f).absoluteFilePath());
         bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
-        cout << "File: " << bib_file << endl;
+        cout << "File: " << bib_file << _QT_6_endl;
         while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
         {
             const QString author(reference.value("author"));
@@ -250,7 +250,7 @@ void c2bTests::heuristic_author()
             continue;
         if (dc.at(0).isLetter() && dc.at(1).isLetter())
             cout << '[' << c << ']' << " u: " << u << " decompose: " << decomposition(c)
-                 << " category: " << c.category() << endl;
+                 << " category: " << c.category() << _QT_6_endl;
     }
     return;
 #endif
@@ -262,7 +262,7 @@ void c2bTests::heuristic_author()
         const QString bib_file(flist.at(f).absoluteFilePath());
         fields.append("file");
         bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
-        cout << "File: " << bib_file << endl;
+        cout << "File: " << bib_file << _QT_6_endl;
         while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
         {
             const QString file(reference.value("file"));
@@ -272,8 +272,8 @@ void c2bTests::heuristic_author()
             {
                 if (doc.at(i).unicode() > 800 && doc.at(i).unicode() < 900)
                 {
-                    cout << "At file: " << file << endl;
-                    cout << '[' << doc.at(i) << "] " << doc.mid(i - 10, 20) << endl;
+                    cout << "At file: " << file << _QT_6_endl;
+                    cout << '[' << doc.at(i) << "] " << doc.mid(i - 10, 20) << _QT_6_endl;
                 }
                 charfreq.insert(doc.at(i), 1 + charfreq.value(doc.at(i), 0));
             }
@@ -284,25 +284,25 @@ void c2bTests::heuristic_author()
     for (int i = 0; i < cl.count(); ++i)
         cout << '[' << cl.at(i) << ']' << " u: " << cl.at(i).unicode() << " letter: " << cl.at(i).isLetter()
              << " decompose: " << decomposition(cl.at(i)) << " category: " << cl.at(i).category()
-             << " f: " << charfreq.value(cl.at(i)) << endl;
-    cout << "\nTotal characters: " << char_count << endl;
+             << " f: " << charfreq.value(cl.at(i)) << _QT_6_endl;
+    cout << "\nTotal characters: " << char_count << _QT_6_endl;
     return;
 #endif
 #if C2B_CHECK_PDF_AUTHORS
-    cout << endl;
-    cout << "----------------------------------------" << endl;
-    cout << "Test heuristic author recognition on PDF" << endl;
-    cout << "----------------------------------------" << endl;
-    cout << endl;
-    cout << "Checking files at: " << _bibliographic_dir << endl;
+    cout << _QT_6_endl;
+    cout << "----------------------------------------" << _QT_6_endl;
+    cout << "Test heuristic author recognition on PDF" << _QT_6_endl;
+    cout << "----------------------------------------" << _QT_6_endl;
+    cout << _QT_6_endl;
+    cout << "Checking files at: " << _bibliographic_dir << _QT_6_endl;
 
     const QStringList excluded(c2bUtils::fileToString(_bibliographic_dir + "/c2b_test_exclude.txt")
-                               .split(QRegExp("[\\n\\r]"), QString::SkipEmptyParts));
+                               .split(QRegExp("[\\n\\r]"), _QT_6_SkipEmptyParts));
     QHash<QString, QString> doc_cache;
     const QString doc_cache_fn(_bibliographic_dir + "/c2b_test.cache");
     if (QFileInfo::exists(doc_cache_fn))
     {
-        cout << "Reading from cache" << endl;
+        cout << "Reading from cache" << _QT_6_endl;
         QFile file(doc_cache_fn);
         file.open(QIODevice::ReadOnly);
         QDataStream ds(&file);
@@ -315,7 +315,7 @@ void c2bTests::heuristic_author()
             const QString bib_file(flist.at(f).absoluteFilePath());
             fields.append("file");
             bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
-            cout << "File: " << bib_file << endl;
+            cout << "File: " << bib_file << _QT_6_endl;
             while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
             {
                 const QString file(reference.value("file"));
@@ -332,11 +332,11 @@ void c2bTests::heuristic_author()
             file.open(QIODevice::WriteOnly);
             QDataStream ds(&file);
             ds << doc_cache;
-            cout << "Writing cache " << doc_cache_fn << endl;
-            cout << "Delete cache when done" << endl;
+            cout << "Writing cache " << doc_cache_fn << _QT_6_endl;
+            cout << "Delete cache when done" << _QT_6_endl;
         }
     }
-    cout << "Check authors" << endl;
+    cout << "Check authors" << _QT_6_endl;
     int n_pdf(0);
     int n_failed_pdf(0);
     for (int f = 0; f < flist.count(); ++f)
@@ -344,7 +344,7 @@ void c2bTests::heuristic_author()
         const QString bib_file(flist.at(f).absoluteFilePath());
         fields.append("file");
         bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
-        cout << "File: " << bib_file << endl;
+        cout << "File: " << bib_file << _QT_6_endl;
         while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
         {
             const QString file(reference.value("file"));
@@ -377,11 +377,11 @@ void c2bTests::heuristic_author()
                     qDebug() << author;
                     qDebug() << guess;
                     qDebug() << reference.value("file");
-                    qDebug() << "DOCUMENT: \n" << doc << endl << endl;
+                    qDebug() << "DOCUMENT: \n" << doc << _QT_6_endl << _QT_6_endl;
                     //                    for (int i = 0; i < doc.count(); ++i)
                     //                        cout << '[' << doc.at(i) << ']' << " u: " << doc.at(i).unicode() << "
                     //                        letter: " <<
-                    //                             doc.at(i).isLetter() << endl;
+                    //                             doc.at(i).isLetter() << _QT_6_endl;
                 }
                 cout << QString("          '%1'\n").arg(guess);
             }
@@ -392,8 +392,8 @@ void c2bTests::heuristic_author()
                 ++n_failed_pdf;
         }
     }
-    cout << "PDF Tests: " << n_pdf << endl;
-    cout << "Succeded: " << n_pdf - n_failed_pdf << endl;
+    cout << "PDF Tests: " << n_pdf << _QT_6_endl;
+    cout << "Succeded: " << n_pdf - n_failed_pdf << _QT_6_endl;
     _test_count += n_pdf;
     _failed_test_count += n_failed_pdf;
 #endif
@@ -402,14 +402,14 @@ void c2bTests::heuristic_author()
 void c2bTests::check_abbreviations_txt()
 {
 #if C2B_CHECK_JOURNALS
-    cout << endl;
-    cout << "--------------------------------" << endl;
-    cout << "Check journal abbreviations file" << endl;
-    cout << "--------------------------------" << endl;
-    cout << endl;
+    cout << _QT_6_endl;
+    cout << "--------------------------------" << _QT_6_endl;
+    cout << "Check journal abbreviations file" << _QT_6_endl;
+    cout << "--------------------------------" << _QT_6_endl;
+    cout << _QT_6_endl;
 
     const QString dbfile(settings::instance()->fileName("cb2Bib/JournalFile"));
-    cout << dbfile << endl;
+    cout << dbfile << _QT_6_endl;
     journalDB jdb(dbfile);
 
     QStringList abbr1, abbr2, full1, full2, code;
@@ -428,24 +428,24 @@ void c2bTests::check_abbreviations_txt()
             ++line_number;
             if (line.isEmpty() || line.startsWith('#'))
                 continue;
-            const QStringList spLine(line.split('|', QString::SkipEmptyParts));
+            const QStringList spLine(line.split('|', _QT_6_SkipEmptyParts));
             if (spLine.count() != 3)
             {
-                cout << "Syntax error in journal file at line " << line_number << endl;
+                cout << "Syntax error in journal file at line " << line_number << _QT_6_endl;
                 continue;
             }
-            const QStringList spAbbreviated(spLine.at(1).split('=', QString::SkipEmptyParts));
+            const QStringList spAbbreviated(spLine.at(1).split('=', _QT_6_SkipEmptyParts));
             const int na(spAbbreviated.count());
             if (na < 1 || na > 2)
             {
-                cout << "Syntax error in journal file at line " << line_number << endl;
+                cout << "Syntax error in journal file at line " << line_number << _QT_6_endl;
                 continue;
             }
-            const QStringList spExtended(spLine.at(2).split('=', QString::SkipEmptyParts));
+            const QStringList spExtended(spLine.at(2).split('=', _QT_6_SkipEmptyParts));
             const int ne(spExtended.count());
             if (ne < 1 || ne > 2)
             {
-                cout << "Syntax error in journal file at line " << line_number << endl;
+                cout << "Syntax error in journal file at line " << line_number << _QT_6_endl;
                 continue;
             }
             code += spLine.at(0);
@@ -460,131 +460,131 @@ void c2bTests::check_abbreviations_txt()
         for (int i = 0; i < njournals; ++i)
             counter += code.at(i).toLower().remove(c2bUtils::nonLetter);
         counter.removeDuplicates();
-        cout << "code total:  " << njournals << " unique: " << counter.count() << endl;
+        cout << "code total:  " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
             counter += abbr1.at(i).toLower().remove(c2bUtils::nonLetter);
         counter.removeDuplicates();
-        cout << "abbr1 total: " << njournals << " unique: " << counter.count() << endl;
+        cout << "abbr1 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
             counter += full1.at(i).toLower().remove(c2bUtils::nonLetter);
         counter.removeDuplicates();
-        cout << "full1 total: " << njournals << " unique: " << counter.count() << endl;
+        cout << "full1 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
             counter += abbr2.at(i).toLower().remove(c2bUtils::nonLetter);
         counter.removeDuplicates();
-        cout << "abbr2 total: " << njournals << " unique: " << counter.count() << endl;
+        cout << "abbr2 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
             counter += full2.at(i).toLower().remove(c2bUtils::nonLetter);
         counter.removeDuplicates();
-        cout << "full2 total: " << njournals << " unique: " << counter.count() << endl;
+        cout << "full2 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
     }
     const int njournals(code.count());
 
-    cout << endl;
+    cout << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(code.at(i)) != abbr1.at(i))
             cout << "failed code to abbr1   " << code.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(code.at(i))
-                 << endl;
+                 << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(code.at(i)) != abbr2.at(i))
             cout << "failed code to abbr2   " << code.at(i) << " | " << abbr2.at(i) << " | "
-                 << jdb.retrieveAlternate(code.at(i)) << endl;
+                 << jdb.retrieveAlternate(code.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(code.at(i)) != full1.at(i))
             cout << "failed code to full1   " << code.at(i) << " | " << full1.at(i) << " | "
-                 << jdb.retrieveFull(code.at(i)) << endl;
+                 << jdb.retrieveFull(code.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(code.at(i)) != full2.at(i))
             cout << "failed code to full2   " << code.at(i) << " | " << full2.at(i) << " | "
-                 << jdb.retrieveAlternateFull(code.at(i)) << endl;
+                 << jdb.retrieveAlternateFull(code.at(i)) << _QT_6_endl;
 
-    cout << endl;
+    cout << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(abbr1.at(i)) != abbr1.at(i))
             cout << "failed abbr1 to abbr1  " << abbr1.at(i) << " | " << abbr1.at(i) << " | "
-                 << jdb.retrieve(abbr1.at(i)) << endl;
+                 << jdb.retrieve(abbr1.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(abbr1.at(i)) != abbr2.at(i))
             cout << "failed abbr1 to abbr2  " << abbr1.at(i) << " | " << abbr2.at(i) << " | "
-                 << jdb.retrieveAlternate(abbr1.at(i)) << endl;
+                 << jdb.retrieveAlternate(abbr1.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(abbr1.at(i)) != full1.at(i))
             cout << "failed abbr1 to full1  " << abbr1.at(i) << " | " << full1.at(i) << " | "
-                 << jdb.retrieveFull(abbr1.at(i)) << endl;
+                 << jdb.retrieveFull(abbr1.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(abbr1.at(i)) != full2.at(i))
             cout << "failed abbr1 to full2  " << abbr1.at(i) << " | " << full2.at(i) << " | "
-                 << jdb.retrieveAlternateFull(abbr1.at(i)) << endl;
+                 << jdb.retrieveAlternateFull(abbr1.at(i)) << _QT_6_endl;
 
-    cout << endl;
+    cout << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(abbr2.at(i)) != abbr1.at(i))
             cout << "failed abbr2 to abbr1  " << abbr2.at(i) << " | " << abbr1.at(i) << " | "
-                 << jdb.retrieve(abbr2.at(i)) << endl;
+                 << jdb.retrieve(abbr2.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(abbr2.at(i)) != abbr2.at(i))
             cout << "failed abbr2 to abbr2  " << abbr2.at(i) << " | " << abbr2.at(i) << " | "
-                 << jdb.retrieveAlternate(abbr2.at(i)) << endl;
+                 << jdb.retrieveAlternate(abbr2.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(abbr2.at(i)) != full1.at(i))
             cout << "failed abbr2 to full1  " << abbr2.at(i) << " | " << full1.at(i) << " | "
-                 << jdb.retrieveFull(abbr2.at(i)) << endl;
+                 << jdb.retrieveFull(abbr2.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(abbr2.at(i)) != full2.at(i))
             cout << "failed abbr2 to full2  " << abbr2.at(i) << " | " << full2.at(i) << " | "
-                 << jdb.retrieveAlternateFull(abbr2.at(i)) << endl;
+                 << jdb.retrieveAlternateFull(abbr2.at(i)) << _QT_6_endl;
 
-    cout << endl;
+    cout << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(full1.at(i)) != abbr1.at(i))
             cout << "failed full1 to abbr1  " << full1.at(i) << " | " << abbr1.at(i) << " | "
-                 << jdb.retrieve(full1.at(i)) << endl;
+                 << jdb.retrieve(full1.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(full1.at(i)) != abbr2.at(i))
             cout << "failed full1 to abbr2  " << full1.at(i) << " | " << abbr2.at(i) << " | "
-                 << jdb.retrieveAlternate(full1.at(i)) << endl;
+                 << jdb.retrieveAlternate(full1.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(full1.at(i)) != full1.at(i))
             cout << "failed full1 to full1  " << full1.at(i) << " | " << full1.at(i) << " | "
-                 << jdb.retrieveFull(full1.at(i)) << endl;
+                 << jdb.retrieveFull(full1.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(full1.at(i)) != full2.at(i))
             cout << "failed full1 to full2  " << full1.at(i) << " | " << full2.at(i) << " | "
-                 << jdb.retrieveAlternateFull(full1.at(i)) << endl;
+                 << jdb.retrieveAlternateFull(full1.at(i)) << _QT_6_endl;
 
-    cout << endl;
+    cout << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(full2.at(i)) != abbr1.at(i))
             cout << "failed full2 to abbr1  " << full2.at(i) << " | " << abbr1.at(i) << " | "
-                 << jdb.retrieve(full2.at(i)) << endl;
+                 << jdb.retrieve(full2.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(full2.at(i)) != abbr2.at(i))
             cout << "failed full2 to abbr2  " << full2.at(i) << " | " << abbr2.at(i) << " | "
-                 << jdb.retrieveAlternate(full2.at(i)) << endl;
+                 << jdb.retrieveAlternate(full2.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(full2.at(i)) != full1.at(i))
             cout << "failed full2 to full1  " << full2.at(i) << " | " << full1.at(i) << " | "
-                 << jdb.retrieveFull(full2.at(i)) << endl;
+                 << jdb.retrieveFull(full2.at(i)) << _QT_6_endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(full2.at(i)) != full2.at(i))
             cout << "failed full2 to full2  " << full2.at(i) << " | " << full2.at(i) << " | "
-                 << jdb.retrieveAlternateFull(full2.at(i)) << endl;
+                 << jdb.retrieveAlternateFull(full2.at(i)) << _QT_6_endl;
 #endif
 }
 
 void c2bTests::heuristic_journal()
 {
 #if C2B_CHECK_JOURNALS
-    cout << endl;
-    cout << "-----------------------------------------" << endl;
-    cout << "Test heuristic journal recognition on PDF" << endl;
-    cout << "-----------------------------------------" << endl;
-    cout << endl;
-    cout << "Checking files at: " << _bibliographic_dir << endl;
+    cout << _QT_6_endl;
+    cout << "-----------------------------------------" << _QT_6_endl;
+    cout << "Test heuristic journal recognition on PDF" << _QT_6_endl;
+    cout << "-----------------------------------------" << _QT_6_endl;
+    cout << _QT_6_endl;
+    cout << "Checking files at: " << _bibliographic_dir << _QT_6_endl;
 
     QFileInfoList flist = QDir(_bibliographic_dir).entryInfoList(QStringList() << "*.bib");
     bibParser bp;
@@ -594,12 +594,12 @@ void c2bTests::heuristic_journal()
     fields.append("file");
 
     const QStringList excluded(c2bUtils::fileToString(_bibliographic_dir + "/c2b_test_exclude.txt")
-                               .split(QRegExp("[\\n\\r]"), QString::SkipEmptyParts));
+                               .split(QRegExp("[\\n\\r]"), _QT_6_SkipEmptyParts));
     QHash<QString, QString> doc_cache;
     const QString doc_cache_fn(_bibliographic_dir + "/c2b_test.cache");
     if (QFileInfo(doc_cache_fn).exists())
     {
-        cout << "Reading from cache" << endl;
+        cout << "Reading from cache" << _QT_6_endl;
         QFile file(doc_cache_fn);
         file.open(QIODevice::ReadOnly);
         QDataStream ds(&file);
@@ -607,10 +607,10 @@ void c2bTests::heuristic_journal()
     }
     else
     {
-        cout << "No cache. Return" << doc_cache_fn << endl;
+        cout << "No cache. Return" << doc_cache_fn << _QT_6_endl;
         return;
     }
-    cout << "Check journals" << endl;
+    cout << "Check journals" << _QT_6_endl;
     int n_pdf(0);
     int n_failed_pdf(0);
     QList<int> doclengths;
@@ -618,7 +618,7 @@ void c2bTests::heuristic_journal()
     {
         const QString bib_file(flist.at(f).absoluteFilePath());
         bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
-        cout << "File: " << bib_file << endl;
+        cout << "File: " << bib_file << _QT_6_endl;
         while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
         {
             const QString file(reference.value("file"));
@@ -657,7 +657,7 @@ void c2bTests::heuristic_journal()
                 qDebug() << "jn:" << fjournal;
                 qDebug() << "gn:" << guess;
                 qDebug() << reference.value("file");
-                qDebug() << "DOCUMENT: \n" << doc << endl << endl;
+                qDebug() << "DOCUMENT: \n" << doc << _QT_6_endl << _QT_6_endl;
             }
             else
                 cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(fjournal);
@@ -666,24 +666,24 @@ void c2bTests::heuristic_journal()
                 ++n_failed_pdf;
         }
     }
-    cout << "PDF Tests: " << n_pdf << endl;
-    cout << "Succeded:  " << n_pdf - n_failed_pdf << endl;
-    cout << "Ratio:     " << double(n_pdf) / double(n_failed_pdf) << endl;
+    cout << "PDF Tests: " << n_pdf << _QT_6_endl;
+    cout << "Succeded:  " << n_pdf - n_failed_pdf << _QT_6_endl;
+    cout << "Ratio:     " << double(n_pdf) / double(n_failed_pdf) << _QT_6_endl;
     _test_count += n_pdf;
     _failed_test_count += n_failed_pdf;
 
     std::sort(doclengths.begin(), doclengths.end());
     cout << "doclengths min max median: " << doclengths.first() << ' ' << doclengths.last() << ' '
-         << doclengths.at(doclengths.count() / 2) << endl;
+         << doclengths.at(doclengths.count() / 2) << _QT_6_endl;
 #endif
 }
 
 void c2bTests::author_parser()
 {
-    cout << endl;
-    cout << "------------------" << endl;
-    cout << "Test author parser" << endl;
-    cout << "------------------" << endl;
+    cout << _QT_6_endl;
+    cout << "------------------" << _QT_6_endl;
+    cout << "Test author parser" << _QT_6_endl;
+    cout << "------------------" << _QT_6_endl;
 
     bibParser bp;
     QString author;
@@ -790,7 +790,7 @@ void c2bTests::author_parser()
     input = "YU. DMITRI,3 ANDRIY KARPOFF";
     check_test(author == bp.parse("author", input), input, author);
 
-    cout << "From medline:" << endl;
+    cout << "From medline:" << _QT_6_endl;
     author = "C. L. Maggi III";
     input = "Maggi, Carla L., III";
     check_test(author == bp.parse("author", input), input, author);
@@ -822,10 +822,10 @@ void c2bTests::author_parser()
 
 void c2bTests::heuristic_pvny()
 {
-    cout << endl;
-    cout << "---------------------------------------------------------" << endl;
-    cout << "Test heuristic pages - volume - number - year recognition" << endl;
-    cout << "---------------------------------------------------------" << endl;
+    cout << _QT_6_endl;
+    cout << "---------------------------------------------------------" << _QT_6_endl;
+    cout << "Test heuristic pages - volume - number - year recognition" << _QT_6_endl;
+    cout << "---------------------------------------------------------" << _QT_6_endl;
 
     bibParser bp;
     bibReference reference;
@@ -1113,10 +1113,10 @@ void c2bTests::heuristic_pvny()
 
 void c2bTests::heuristic_misc()
 {
-    cout << endl;
-    cout << "-----------------------------" << endl;
-    cout << "Test miscellaneous heuristics" << endl;
-    cout << "-----------------------------" << endl;
+    cout << _QT_6_endl;
+    cout << "-----------------------------" << _QT_6_endl;
+    cout << "Test miscellaneous heuristics" << _QT_6_endl;
+    cout << "-----------------------------" << _QT_6_endl;
 
     bibParser bp;
     bibReference reference;
@@ -1173,7 +1173,7 @@ void c2bTests::check_test(const bool passed, const QString& input, const QString
 
 void c2bTests::write(const bibParser& bp, const bibReference& reference)
 {
-    cout << endl;
+    cout << _QT_6_endl;
     const QStringList& bibliographicFields = bp.bibliographicFields();
     for (int i = 0; i < bibliographicFields.count(); ++i)
     {
@@ -1182,7 +1182,7 @@ void c2bTests::write(const bibParser& bp, const bibReference& reference)
         {
             const QString& fd = bibliographicFields.at(i);
             const QString padding(QString().fill(' ', 12 - fd.length()));
-            cout << (fd + padding + " = {" + fvalue + '}') << endl;
+            cout << (fd + padding + " = {" + fvalue + '}') << _QT_6_endl;
         }
     }
 }
@@ -1197,11 +1197,11 @@ void c2bTests::heuristic_check_patterns()
     fp.process();
     return;
 #endif
-    cout << endl;
-    cout << "-----------------------------------------------------" << endl;
-    cout << "Check pattern clashes in heuristic author recognition" << endl;
-    cout << "-----------------------------------------------------" << endl;
-    cout << endl;
+    cout << _QT_6_endl;
+    cout << "-----------------------------------------------------" << _QT_6_endl;
+    cout << "Check pattern clashes in heuristic author recognition" << _QT_6_endl;
+    cout << "-----------------------------------------------------" << _QT_6_endl;
+    cout << _QT_6_endl;
     QFileInfoList flist = QDir(_bibliographic_dir).entryInfoList(QStringList() << "*.bib");
     bibParser bp;
     bibReference reference;
@@ -1222,7 +1222,7 @@ void c2bTests::heuristic_check_patterns()
         }
     }
     QStringList word_prefix_lexicon(
-        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, QString::SkipEmptyParts));
+        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
     for (int i = 0; i < word_prefix_lexicon.count(); ++i)
         word_prefix_lexicon[i].replace('_', "\\b");
 
@@ -1235,7 +1235,7 @@ void c2bTests::heuristic_check_patterns()
             const QString& a = anames.at(j);
             wre.setPattern(wp);
             if (a.contains(wre))
-                cout << "LEXICON CLASH: " << wp << ' ' << a << endl;
+                cout << "LEXICON CLASH: " << wp << ' ' << a << _QT_6_endl;
         }
 }
 
