@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2021 by Pere Constans
+ *   Copyright (C) 2004-2024 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_H
@@ -56,6 +56,7 @@ private:
     Ui::cb2Bib ui;
     bool _connected;
     bool _is_check_repeated_done;
+    bool _is_check_ssl_done;
     bool _modified;
     bool _tagged_view_mode;
     bool isReferenceRepeated();
@@ -70,6 +71,7 @@ private:
     void annoteEditor(const QString& annotefile);
     void c2bParse(const QString& text);
     void c2bPreparse(const QString& text);
+    void checkNetQuerySsl();
     void closeEvent(QCloseEvent* qevent);
     void dragEnterEvent(QDragEnterEvent* qevent);
     void dropEvent(QDropEvent* qevent);
@@ -127,7 +129,7 @@ private slots:
     void selectFile();
     void setDocumentFilename();
     void setTaggedClipEditMode(bool tagged);
-    void setWindowTitle(const QString& title = QString());
+    void setWindowTitle();
     void showLink(const QString& ln);
     void showMessage(const QString& ms);
     void toggleReferenceTabs();
